#!/usr/bin/env python

import libxml2dom.xmlrpc

# Some examples from the specification.

request = """<?xml version="1.0"?>
<methodCall>
   <methodName>examples.getStateName</methodName>
   <params>
      <param>
         <value><i4>41</i4></value>
         </param>
      </params>
   </methodCall>"""

req = libxml2dom.xmlrpc.parseString(request)
assert req.methodName == "examples.getStateName"
assert req.parameterValues == [41]
assert req.fault is None
print "Method name:", req.methodName
print "Parameter values:", req.parameterValues
print "Fault:", req.fault

response = """<?xml version="1.0"?>
<methodResponse>
   <params>
      <param>
         <value><string>South Dakota</string></value>
         </param>
      </params>
   </methodResponse>"""

resp = libxml2dom.xmlrpc.parseString(response)
assert resp.methodName is None
assert resp.parameterValues == ["South Dakota"]
assert resp.fault is None
print "Method name:", resp.methodName
print "Parameter values:", resp.parameterValues
print "Fault:", resp.fault

failed = """<?xml version="1.0"?>
<methodResponse>
   <fault>
      <value>
         <struct>
            <member>
               <name>faultCode</name>
               <value><int>4</int></value>
               </member>
            <member>
               <name>faultString</name>
               <value><string>Too many parameters.</string></value>
               </member>
            </struct>
         </value>
      </fault>
   </methodResponse>"""

f = libxml2dom.xmlrpc.parseString(failed)
assert f.methodName is None
assert f.parameterValues == []
assert f.fault.code == "4"
assert f.fault.reason == "Too many parameters."
print "Method name:", f.methodName
print "Parameter values:", f.parameterValues
print "Fault code:", f.fault.code

# Python Package Index examples.

search = """<?xml version="1.0"?>
<methodCall>
  <methodName>search</methodName>
  <params>
    <param>
      <value>
        <struct>
          <member>
            <name>name</name>
            <value><string>libxml2dom</string></value>
          </member>
          <member>
            <name>description</name>
            <value>XML</value>
          </member>
        </struct>
      </value>
    </param>
    <param>
      <value>
        <string>and</string>
      </value>
    </param>
  </params>
</methodCall>"""

s = libxml2dom.xmlrpc.parseString(search)
assert s.methodName == "search"
assert s.parameterValues == [[("name", "libxml2dom"), ("description", "XML")], "and"]
assert s.parameterItems == [
    (None, [("name", "libxml2dom"), ("description", "XML")]),
    (None, "and")
    ]
assert s.fault is None
print "Method name:", s.methodName
print "Parameter values:", s.parameterValues
print "Parameter items:", s.parameterItems
print "Parameter map:", s.parameterMap
print "Fault:", s.fault

# vim: tabstop=4 expandtab shiftwidth=4
